@@ -6,15 +6,17 @@
 
 """Module checking Spyder runtime dependencies"""
 
-
+# Standard library imports
 import os
+import os.path as osp
 import sys
 
 # Local imports
-from spyder.utils import programs
-from spyder.config.base import _, is_pynsist
+from spyder.config.base import _, DEV, is_pynsist, running_under_pytest
 from spyder.config.utils import is_anaconda
+from spyder.utils import programs
 
+HERE = osp.dirname(osp.abspath(__file__))
 
 # =============================================================================
 # Kind of dependency
@@ -32,6 +34,7 @@ APPLAUNCHSERVICES_REQVER = '>=0.1.7'
 ATOMICWRITES_REQVER = '>=1.2.0'
 CHARDET_REQVER = '>=2.0.0'
 CLOUDPICKLE_REQVER = '>=0.5.0'
+COOKIECUTTER_REQVER = '>=1.6.0'
 DIFF_MATCH_PATCH_REQVER = '>=20181111'
 # None for pynsist install for now
 # (check way to add dist.info/egg.info from packages without wheels available)
@@ -54,14 +57,15 @@ PYLS_BLACK_REQVER = '>=0.4.6'
 PYLS_SPYDER_REQVER = '>=0.3.2'
 PYXDG_REQVER = '>=0.26'
 PYZMQ_REQVER = '>=17'
-QDARKSTYLE_REQVER = '>=2.8;<3.0'
-QTAWESOME_REQVER = '>=0.5.7'
+QDARKSTYLE_REQVER = '=3.0.2'
+QSTYLIZER_REQVER = '>=0.1.10'
+QTAWESOME_REQVER = '>=1.0.2'
 QTCONSOLE_REQVER = '>=5.0.3'
 QTPY_REQVER = '>=1.5.0'
 RTREE_REQVER = '>=0.8.3'
 SETUPTOOLS_REQVER = '>=39.0.0'
 SPHINX_REQVER = '>=0.6.6'
-SPYDER_KERNELS_REQVER = '>=1.10.2;<1.11.0'
+SPYDER_KERNELS_REQVER = '>=2.0.1;<2.1.0'
 TEXTDISTANCE_REQVER = '>=4.2.0'
 THREE_MERGE_REQVER = '>=0.1.1'
 # None for pynsist install for now
@@ -103,6 +107,10 @@ DESCRIPTIONS = [
      'package_name': "cloudpickle",
      'features': _("Handle communications between kernel and frontend"),
      'required_version': CLOUDPICKLE_REQVER},
+    {'modname': "cookiecutter",
+     'package_name': "cookiecutter",
+     'features': _("Create projects from cookiecutter templates"),
+     'required_version': COOKIECUTTER_REQVER},
     {'modname': "diff_match_patch",
      'package_name': "diff-match-patch",
      'features': _("Compute text file diff changes during edition"),
@@ -192,6 +200,10 @@ DESCRIPTIONS = [
      'package_name': "qdarkstyle",
      'features': _("Dark style for the entire interface"),
      'required_version': QDARKSTYLE_REQVER},
+    {'modname': "qstylizer",
+     'package_name': "qstylizer",
+     'features': _("Customize Qt stylesheets"),
+     'required_version': QSTYLIZER_REQVER},
     {'modname': "qtawesome",
      'package_name': "qtawesome",
      'features': _("Icon theme based on FontAwesome and Material Design icons"),
@@ -232,7 +244,7 @@ DESCRIPTIONS = [
     {'modname': "watchdog",
      'package_name': "watchdog",
      'features': _("Watch file changes on project directories"),
-     'required_version': WATCHDOG_REQVER}
+     'required_version': WATCHDOG_REQVER},
 ]
 
 
@@ -347,7 +359,7 @@ def check(modname):
         if dependency.modname == modname:
             return dependency.check()
     else:
-        raise RuntimeError("Unkwown dependency %s" % modname)
+        raise RuntimeError("Unknown dependency %s" % modname)
 
 
 def status(deps=DEPENDENCIES, linesep=os.linesep):
@@ -391,6 +403,14 @@ def missing_dependencies():
     """Return the status of missing dependencies (if any)"""
     missing_deps = []
     for dependency in DEPENDENCIES:
+        # Skip checking dependencies for which we have subrepos
+        if DEV or running_under_pytest():
+            repo_path = osp.normpath(osp.join(HERE, '..'))
+            subrepos_path = osp.join(repo_path, 'external-deps')
+            subrepos = os.listdir(subrepos_path)
+            if dependency.package_name in subrepos:
+                continue
+
         if dependency.kind != OPTIONAL and not dependency.check():
             missing_deps.append(dependency)
 
